/*
 * util.c -- a small collection of utility functions for nash and libnash.a
 *
 * Copyright 2006-2008 Red Hat, Inc.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author(s): Peter Jones <pjones@redhat.com>
 */

#define _GNU_SOURCE 1

#include <unistd.h>
#include <errno.h>
#include <stdlib.h>
#include <string.h>

#include <nash.h>
#include "lib.h"
#include "util.h"

char *
readlink_malloc(const char *filename)
{
    int size=100;
    char *buffer = NULL;

    while (1) {
        int nchars;

        buffer = (char *)realloc(buffer, size);
        memset(buffer, '\0', size);
        if (!buffer)
            return NULL;
        nchars = readlink(filename, buffer, size-1);
        if (nchars < 0) {
            free(buffer);
            return NULL;
        }
        if (nchars < size-1)
            return buffer;
        size *= 2;
    }
}

nashContext *_nash_context = NULL;

int
qprintf(const char *format, ...)
{
    va_list ap;
    int ret;

    va_start(ap, format);
    ret = _nash_context->logger(_nash_context, NASH_NOTICE, format, ap);
    va_end(ap);

    return ret;
}

int
eprintf(const char *format, ...)
{
    va_list ap;
    int ret;

    va_start(ap, format);
    ret = _nash_context->logger(_nash_context, NASH_ERROR, format, ap);
    va_end(ap);

    return ret;
}

/*
 * vim:ts=8:sw=4:sts=4:et
 */
